@@ -40,6 +40,7 @@ mod from;
 mod from_bytes;
 mod from_str_radix;
 mod gcd;
+mod hash;
 mod mul;
 mod mul_assign;
 mod neg;
@@ -51,6 +52,7 @@ mod partial_eq;
 mod partial_ord;
 mod pow;
 mod rem;
+mod rem_assign;
 mod rem_euclid;
 mod sub;
 mod sub_assign;
