@@ -7,47 +7,40 @@ use std::ops::{
     Mul, MulAssign, Neg, Not, Rem, Shl, ShlAssign, Shr, ShrAssign, Sub, SubAssign,
 };
 
-pub trait AdditiveMonoid<Other = Self> = Add<Other, Output = Self> + Zeroable;
+pub trait AdditiveMonoid = Add<Self, Output = Self> + Sized + Zeroable;
 
-pub trait AdditiveGroup<Other = Self> = AdditiveMonoid<Other> + SubtractiveMagma<Other>;
+pub trait AdditiveGroup = AdditiveMonoid + SubtractiveMagma;
 
-pub trait AssigningAdditiveMonoid<Other = Self> = AdditiveMonoid<Other> + AddAssign<Other>;
+pub trait AssigningAdditiveMonoid = AdditiveMonoid + AddAssign<Self>;
 
-pub trait AssigningAdditiveGroup<Other = Self> =
-    AssigningAdditiveMonoid<Other> + AssigningSubtractiveMagma<Other>;
+pub trait AssigningAdditiveGroup = AssigningAdditiveMonoid + AssigningSubtractiveMagma;
 
-pub trait AssigningBitwiseConjunctiveMagma<Other = Self> =
-    BitwiseConjunctiveMagma<Other> + BitAndAssign<Other>;
+pub trait AssigningBitwiseConjunctiveMagma = BitwiseConjunctiveMagma + BitAndAssign<Self>;
 
-pub trait AssigningBitwiseDisjunctiveMonoid<Other = Self> =
-    BitwiseDisjunctiveMonoid<Other> + BitOrAssign<Other>;
+pub trait AssigningBitwiseDisjunctiveMonoid = BitwiseDisjunctiveMonoid + BitOrAssign<Self>;
 
-pub trait AssigningBitwiseExclusiveDisjunctiveMonoid<Other = Self> =
-    BitwiseExclusiveDisjunctiveMonoid<Other> + BitXorAssign<Other>;
+pub trait AssigningBitwiseExclusiveDisjunctiveMonoid =
+    BitwiseExclusiveDisjunctiveMonoid + BitXorAssign<Self>;
 
-pub trait AssigningDivisivePartialMagma<Divisor = Self> =
-    DivisivePartialMagma<Divisor> + DivAssign<Divisor>;
+pub trait AssigningDivisivePartialMagma = DivisivePartialMagma + DivAssign<Self>;
 
-pub trait AssigningMultiplicativeMonoid<Other = Self> =
-    MultiplicativeMonoid<Other> + MulAssign<Other>;
+pub trait AssigningMultiplicativeMonoid = MultiplicativeMonoid + MulAssign<Self>;
 
-pub trait AssigningShiftingLeftMonoid<Shift = Self> = ShiftingLeftMonoid<Shift> + ShlAssign<Shift>;
+pub trait AssigningShiftableLeftBy<Shift = Self> = ShiftableLeftBy<Shift> + ShlAssign<Shift>;
 
-pub trait AssigningShiftingRightMonoid<Shift = Self> =
-    ShiftingRightMonoid<Shift> + ShrAssign<Shift>;
+pub trait AssigningShiftableRightBy<Shift = Self> = ShiftableRightBy<Shift> + ShrAssign<Shift>;
 
-pub trait AssigningSubtractiveMagma<Subtrahend = Self> =
-    SubtractiveMagma<Subtrahend> + SubAssign<Subtrahend>;
+pub trait AssigningSubtractiveMagma = SubtractiveMagma + SubAssign<Self>;
 
-pub trait BitwiseConjunctiveMagma<Other = Self> = BitAnd<Other, Output = Self> + Zeroable;
+pub trait BitwiseConjunctiveMagma = BitAnd<Self, Output = Self> + Sized + Zeroable;
 
-pub trait BitwiseDisjunctiveMonoid<Other = Self> = BitOr<Other, Output = Self> + Zeroable;
+pub trait BitwiseDisjunctiveMonoid = BitOr<Self, Output = Self> + Sized + Zeroable;
 
-pub trait BitwiseExclusiveDisjunctiveMonoid<Other = Self> = BitXor<Other, Output = Self> + Zeroable;
+pub trait BitwiseExclusiveDisjunctiveMonoid = BitXor<Self, Output = Self> + Sized + Zeroable;
 
 pub trait BitwiseNegatableUnaryAlgebra = Not<Output = Self>;
 
-pub trait DivisivePartialMagma<Divisor = Self> = Div<Divisor, Output = Self>;
+pub trait DivisivePartialMagma = Div<Self, Output = Self> + Sized;
 
 pub trait Float = AssigningAdditiveMonoid
     + AssigningDivisivePartialMagma
@@ -63,23 +56,23 @@ pub trait Float = AssigningAdditiveMonoid
     + MinExp
     + PartialEq;
 
-pub trait GcdMagma<Other = Self> = Gcd<Other, Output = Self>;
+pub trait GcdMagma = Gcd<Self, Output = Self> + Sized;
 
 pub trait ModularUnaryAlgebra = Abs<Output = Self>;
 
-pub trait ModularPartialMagma<Divisor = Self> = RemEuclid<Divisor, Output = Self>;
+pub trait ModularPartialMagma = RemEuclid<Self, Output = Self> + Sized;
 
-pub trait ModularSubtractiveMagma<Subtrahend = Self> = WrappingSub<Subtrahend, Output = Self>;
+pub trait ModularSubtractiveMagma = WrappingSub<Self, Output = Self> + Sized;
 
-pub trait MultiplicativeMonoid<Other = Self> = Mul<Other, Output = Self> + Unitary;
+pub trait MultiplicativeMonoid = Mul<Self, Output = Self> + Sized + Unitary;
 
 pub trait NegatableUnaryAlgebra = Neg<Output = Self>;
 
-pub trait ShiftingLeftMonoid<Shift = Self> = Shl<Shift, Output = Self> + Zeroable;
+pub trait ShiftableLeftBy<Shift = Self> = Shl<Shift, Output = Self>;
 
-pub trait ShiftingRightMonoid<Shift = Self> = Shr<Shift, Output = Self> + Zeroable;
+pub trait ShiftableRightBy<Shift = Self> = Shr<Shift, Output = Self>;
 
-pub trait SubtractiveMagma<Subtrahend = Self> = Sub<Subtrahend, Output = Self>;
+pub trait SubtractiveMagma = Sized + Sub<Self, Output = Self>;
 
 pub trait Abs {
     type Output;
@@ -645,14 +638,14 @@ macro_rules! signed_checked_shl_impl {
             type Output = Option<$t>;
 
             #[inline(always)]
-            fn checked_shl(self, other: $f) -> Self::Output {
-                if other < 0 {
+            fn checked_shl(self, shift: $f) -> Self::Output {
+                if shift < 0 {
                     None
                 } else {
-                    if self.leading_zeros() < u32::try_from(other).ok()? {
+                    if self.leading_zeros() < u32::try_from(shift).ok()? {
                         None
                     } else {
-                        Some(self << other)
+                        Some(self << shift)
                     }
                 }
             }
@@ -661,16 +654,16 @@ macro_rules! signed_checked_shl_impl {
 }
 
 macro_rules! unsigned_checked_shl_impl {
-    ($t:ty, $f:ty) => {
-        impl CheckedShl<$f> for $t {
+    ($b:ty, $s:ty) => {
+        impl CheckedShl<$s> for $b {
             type Output = Option<Self>;
 
             #[inline(always)]
-            fn checked_shl(self, other: $f) -> Self::Output {
-                if self.leading_zeros() < u32::try_from(other).ok()? {
+            fn checked_shl(self, shift: $s) -> Self::Output {
+                if self.leading_zeros() < u32::try_from(shift).ok()? {
                     None
                 } else {
-                    Some(self << other)
+                    Some(self << shift)
                 }
             }
         }
@@ -678,20 +671,20 @@ macro_rules! unsigned_checked_shl_impl {
 }
 
 macro_rules! primitive_checked_shl_impl {
-    ($($t:ty)*) => ($(
-        signed_checked_shl_impl! { $t, i8 }
-        signed_checked_shl_impl! { $t, i16 }
-        signed_checked_shl_impl! { $t, i32 }
-        signed_checked_shl_impl! { $t, i64 }
-        signed_checked_shl_impl! { $t, i128 }
-        signed_checked_shl_impl! { $t, isize }
+    ($($b:ty)*) => ($(
+        signed_checked_shl_impl! { $b, i8 }
+        signed_checked_shl_impl! { $b, i16 }
+        signed_checked_shl_impl! { $b, i32 }
+        signed_checked_shl_impl! { $b, i64 }
+        signed_checked_shl_impl! { $b, i128 }
+        signed_checked_shl_impl! { $b, isize }
 
-        unsigned_checked_shl_impl! { $t, u8 }
-        unsigned_checked_shl_impl! { $t, u16 }
-        unsigned_checked_shl_impl! { $t, u32 }
-        unsigned_checked_shl_impl! { $t, u64 }
-        unsigned_checked_shl_impl! { $t, u128 }
-        unsigned_checked_shl_impl! { $t, usize }
+        unsigned_checked_shl_impl! { $b, u8 }
+        unsigned_checked_shl_impl! { $b, u16 }
+        unsigned_checked_shl_impl! { $b, u32 }
+        unsigned_checked_shl_impl! { $b, u64 }
+        unsigned_checked_shl_impl! { $b, u128 }
+        unsigned_checked_shl_impl! { $b, usize }
     )*)
 }
 
@@ -704,16 +697,16 @@ pub trait CheckedShr<Shift = Self> {
 }
 
 macro_rules! signed_checked_shr_impl {
-    ($t:ty, $f:ty) => {
-        impl CheckedShr<$f> for $t {
-            type Output = Option<$t>;
+    ($b:ty, $s:ty) => {
+        impl CheckedShr<$s> for $b {
+            type Output = Option<$b>;
 
             #[inline(always)]
-            fn checked_shr(self, other: $f) -> Self::Output {
+            fn checked_shr(self, other: $s) -> Self::Output {
                 if other < 0 {
                     None
                 } else {
-                    <$t>::checked_shr(self, u32::try_from(other).ok()?)
+                    <$b>::checked_shr(self, u32::try_from(other).ok()?)
                 }
             }
         }
@@ -721,33 +714,33 @@ macro_rules! signed_checked_shr_impl {
 }
 
 macro_rules! unsigned_checked_shr_impl {
-    ($t:ty, $f:ty) => {
-        impl CheckedShr<$f> for $t {
+    ($b:ty, $s:ty) => {
+        impl CheckedShr<$s> for $b {
             type Output = Option<Self>;
 
             #[inline(always)]
-            fn checked_shr(self, other: $f) -> Self::Output {
-                <$t>::checked_shr(self, u32::try_from(other).ok()?)
+            fn checked_shr(self, other: $s) -> Self::Output {
+                <$b>::checked_shr(self, u32::try_from(other).ok()?)
             }
         }
     };
 }
 
 macro_rules! primitive_checked_shr_impl {
-    ($($t:ty)*) => ($(
-        signed_checked_shr_impl! { $t, i8 }
-        signed_checked_shr_impl! { $t, i16 }
-        signed_checked_shr_impl! { $t, i32 }
-        signed_checked_shr_impl! { $t, i64 }
-        signed_checked_shr_impl! { $t, i128 }
-        signed_checked_shr_impl! { $t, isize }
+    ($($b:ty)*) => ($(
+        signed_checked_shr_impl! { $b, i8 }
+        signed_checked_shr_impl! { $b, i16 }
+        signed_checked_shr_impl! { $b, i32 }
+        signed_checked_shr_impl! { $b, i64 }
+        signed_checked_shr_impl! { $b, i128 }
+        signed_checked_shr_impl! { $b, isize }
 
-        unsigned_checked_shr_impl! { $t, u8 }
-        unsigned_checked_shr_impl! { $t, u16 }
-        unsigned_checked_shr_impl! { $t, u32 }
-        unsigned_checked_shr_impl! { $t, u64 }
-        unsigned_checked_shr_impl! { $t, u128 }
-        unsigned_checked_shr_impl! { $t, usize }
+        unsigned_checked_shr_impl! { $b, u8 }
+        unsigned_checked_shr_impl! { $b, u16 }
+        unsigned_checked_shr_impl! { $b, u32 }
+        unsigned_checked_shr_impl! { $b, u64 }
+        unsigned_checked_shr_impl! { $b, u128 }
+        unsigned_checked_shr_impl! { $b, usize }
     )*)
 }
 
